==> nextcloud-27.1.4.tgz: nextcloud/apps/serverinfo/l10n/fi.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Suorittimen tietoja ei ole saatavilla",
    "Load average: {cpu} (last minute)" : "Keskimääräinen kuorma: {cpu} (viimeisin minuutti)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Yhteensä: {memTotalBytes}/Nykyinen käyttö: {memUsageBytes}",
    "RAM info not available" : "RAM-tietoja ei saatavilla",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Yhteensä: {swapTotalBytes}/Nykyinen käyttö: {swapUsageBytes}",
    "SWAP info not available" : "SWAP-tietoja ei saatavilla",
    "Copied!" : "Kopioitu!",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "System" : "Järjestelmä",
    "Monitoring" : "Valvonta",
    "Monitoring app with useful server information" : "Valvontasovellus sisältäen hyödyllisiä tietoja palvelimesta",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Näyttää hyödyllisiä tietoja palvelimesta, kuten suorittimen kuorman, muistin ja levytilan käytön, käyttäjien määrän jne.",
    "Operating System:" : "Käyttöjärjestelmä:",
    "CPU:" : "Suoritin:",
    "Unknown Processor" : "Tuntematon suoritin",
    "Memory:" : "Muisti:",
    "Server time:" : "Palvelimen aika:",
    "Uptime:" : "Käynnissäoloaika:",
    "Temperature" : "Lämpötila",
    "Load" : "Kuorma",
    "Memory" : "Muisti",
    "Disk" : "Levy",
    "Mount:" : "Liitospiste:",
    "Filesystem:" : "Tiedostojärjestelmä:",
    "Size:" : "Koko:",
    "Available:" : "Saatavilla:",
    "Used:" : "Käytetty:",
    "Files:" : "Tiedostoja:",
    "Storages:" : "Tallennustilat:",
    "Free Space:" : "Vapaata tilaa:",
    "Network" : "Verkko",
    "Hostname:" : "Tietokoneen nimi:",
    "DNS:" : "Nimipalvelu:",
    "Gateway:" : "Yhdyskäytävä:",
    "Status:" : "Tila:",
    "Speed:" : "Nopeus:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktiiviset käyttäjät",
    "Total users:" : "Käyttäjiä yhteensä:",
    "24 hours:" : "24 tuntia:",
    "1 hour:" : "1 tunti:",
    "5 mins:" : "5 min:",
    "Shares" : "Jaot",
    "Users:" : "Käyttäjiä:",
    "Groups:" : "Ryhmät:",
    "Links:" : "Linkit:",
    "Emails:" : "Sähköpostit:",
    "Talk conversations:" : "Talk-keskustelut:",
    "PHP" : "PHP",
    "Version:" : "Versio:",
    "Memory limit:" : "Muistin raja:",
    "Max execution time:" : "Suoritusaika enintään:",
    "Upload max size:" : "Suurin lähetyksen koko:",
    "Extensions:" : "Laajennukset:",
    "Unable to list extensions" : "Laajennuksia ei voi listata",
    "Database" : "Tietokanta",
    "Type:" : "Tyyppi:",
    "External monitoring tool" : "Ulkopuolinen valvontatyökalu",
    "Copy" : "Kopioi",
    "You will get a notification once one of your disks is nearly full." : "Saat ilmoituksen, kun jokin levyistä on melkein täynnä.",
    "You can connect an external monitoring tool by using this end point:" : "Voit yhdistää ulkopuolisen valvontatyökalun käyttämällä tätä liityntäkohtaa:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Lisää \"?format=json\" URL-osoitteen loppuun saadaksesi tuloksen JSON-muodossa."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.14.tgz: nextcloud/apps/serverinfo/l10n/fi.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Suorittimen tietoja ei ole saatavilla",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Yhteensä: {memTotalBytes}/Nykyinen käyttö: {memUsageBytes}",
    "RAM info not available" : "RAM-tietoja ei saatavilla",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Yhteensä: {swapTotalBytes}/Nykyinen käyttö: {swapUsageBytes}",
    "SWAP info not available" : "SWAP-tietoja ei saatavilla",
    "Copied!" : "Kopioitu!",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "System" : "Järjestelmä",
    "Monitoring" : "Valvonta",
    "Monitoring app with useful server information" : "Valvontasovellus sisältäen hyödyllisiä tietoja palvelimesta",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Näyttää hyödyllisiä tietoja palvelimesta, kuten suorittimen kuorman, muistin ja levytilan käytön, käyttäjien määrän jne.",
    "Operating System:" : "Käyttöjärjestelmä:",
    "CPU:" : "Suoritin:",
    "Unknown Processor" : "Tuntematon suoritin",
    "Memory:" : "Muisti:",
    "Server time:" : "Palvelimen aika:",
    "Uptime:" : "Käynnissäoloaika:",
    "Temperature" : "Lämpötila",
    "Load" : "Kuorma",
    "Memory" : "Muisti",
    "Disk" : "Levy",
    "Mount:" : "Liitospiste:",
    "Filesystem:" : "Tiedostojärjestelmä:",
    "Size:" : "Koko:",
    "Available:" : "Saatavilla:",
    "Used:" : "Käytetty:",
    "Files:" : "Tiedostoja:",
    "Storages:" : "Tallennustilat:",
    "Free Space:" : "Vapaata tilaa:",
    "Network" : "Verkko",
    "Hostname:" : "Tietokoneen nimi:",
    "Gateway:" : "Yhdyskäytävä:",
    "Status:" : "Tila:",
    "Speed:" : "Nopeus:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktiiviset käyttäjät",
    "Last hour" : "Viime tunti",
    "Shares" : "Jaot",
    "Users:" : "Käyttäjiä:",
    "Groups:" : "Ryhmät:",
    "Links:" : "Linkit:",
    "Emails:" : "Sähköpostit:",
    "Talk conversations:" : "Talk-keskustelut:",
    "PHP" : "PHP",
    "Version:" : "Versio:",
    "Memory limit:" : "Muistin raja:",
    "Max execution time:" : "Suoritusaika enintään:",
    "Upload max size:" : "Suurin lähetyksen koko:",
    "Extensions:" : "Laajennukset:",
    "Unable to list extensions" : "Laajennuksia ei voi listata",
    "Database" : "Tietokanta",
    "Type:" : "Tyyppi:",
    "External monitoring tool" : "Ulkopuolinen valvontatyökalu",
    "Copy" : "Kopioi",
    "Load average: {cpu} (last minute)" : "Keskimääräinen kuorma: {cpu} (viimeisin minuutti)",
    "DNS:" : "Nimipalvelu:",
    "Total users:" : "Käyttäjiä yhteensä:",
    "24 hours:" : "24 tuntia:",
    "1 hour:" : "1 tunti:",
    "5 mins:" : "5 min:"
},
"nplurals=2; plural=(n != 1);");
